======
fspath
======

After 10 years juggling with os.path, zipfile & Co. I thought it is time to
bring back more *pythonic* to APIs. It is made with the philosophy that API's
should be intuitive and their defaults should at least cover 80% of what
programmer daily needs.  Started with the semantic file system pathes, it grows
continuous and includes more and more handy stuff for the daily python
scripting.

visit our slide-show at https://return42.github.io/fspath/slides/index.html

:copyright:  Copyright (C) 2023 Markus Heiser
:e-mail:     markus.heiser@darmarIT.de
:license:    GNU Affero General Public License v3 or later (AGPLv3+)
:docs:       http://return42.github.io/fspath
:repository: `github return42/fspath <https://github.com/return42/fspath>`_


Installing
==========

Works as usual, e.g. use::

  pip install --user fspath

or a bleeding edge installation from GitHub::

  pip install --user git+http://github.com/return42/fspath.git
